==> qtjambi-datavisualization-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiDataVisualization/QLogValue3DAxisFormatter_shell.h <==
#ifndef QLOGVALUE3DAXISFORMATTER_SHELL_H
#define QLOGVALUE3DAXISFORMATTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qlogvalue3daxisformatter.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtDataVisualization/qvalue3daxis.h>
#include <QtDataVisualization/qvalue3daxisformatter.h>
#include <QtJambi/RegistryAPI>


class QLogValue3DAxisFormatter_shell : public QLogValue3DAxisFormatter, public QtJambiShellInterface
{
public:
    QLogValue3DAxisFormatter_shell(QObject* parent0 = nullptr);
    ~QLogValue3DAxisFormatter_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QValue3DAxisFormatter* createNewInstance() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void populateCopy(QValue3DAxisFormatter& copy0) const override;
    float positionAt(float value0) const override;
    void recalculate() override;
    QString stringForValue(qreal value0, const QString& format1) const override;
    void timerEvent(QTimerEvent* event0) override;
    float valueAt(float position0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLogValue3DAxisFormatter_access : public QLogValue3DAxisFormatter
{
    jobject __qt_createNewInstance(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_populateCopy_ref_QValue3DAxisFormatter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID copy0) const;
    jfloat __qt_positionAt_float_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat value0) const;
    void __qt_recalculate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jfloat __qt_valueAt_float_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat position0) const;
};

#endif // QLOGVALUE3DAXISFORMATTER_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.6.2.jar: sources/QtJambiDataVisualization/QLogValue3DAxisFormatter_shell.h <==
#ifndef QLOGVALUE3DAXISFORMATTER_SHELL_H
#define QLOGVALUE3DAXISFORMATTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qlogvalue3daxisformatter.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtDataVisualization/qvalue3daxis.h>
#include <QtDataVisualization/qvalue3daxisformatter.h>
#include <QtJambi/RegistryAPI>


class QLogValue3DAxisFormatter_shell : public QLogValue3DAxisFormatter, public QtJambiShellInterface
{
public:
    QLogValue3DAxisFormatter_shell(QObject* parent0 = nullptr);
    ~QLogValue3DAxisFormatter_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QValue3DAxisFormatter* createNewInstance() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void populateCopy(QValue3DAxisFormatter& copy0) const override;
    float positionAt(float value0) const override;
    void recalculate() override;
    QString stringForValue(qreal value0, const QString& format1) const override;
    void timerEvent(QTimerEvent* event0) override;
    float valueAt(float position0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLogValue3DAxisFormatter_access : public QLogValue3DAxisFormatter
{
    jobject __qt_createNewInstance_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_populateCopy_ref_QValue3DAxisFormatter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID copy0) const;
    jfloat __qt_positionAt_float_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat value0) const;
    void __qt_recalculate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jfloat __qt_valueAt_float_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat position0) const;
};

#endif // QLOGVALUE3DAXISFORMATTER_SHELL_H
